@@ -17,7 +17,7 @@ using namespace apolloron;
 
 const char *INKF_PROGNAME = "inkf";
 const char *INKF_BRIEF    = "Yet Another Network Kanji Filter";
-const char *INKF_VERSION  = "1.2.0";
+const char *INKF_VERSION  = "1.2.2";
 const char *INKF_COPY     = "Copyright (C) 2002-2018 Masashi Astro Tachibana";
 const char *INKF_DEF_OUT  = "inkf.out";
 
@@ -80,8 +80,8 @@ int main(int argc, char *argv[]) {
     int retval = 0;
     FILE *fpin = stdin, *fpout = stdout;
     String tmp_str;
-    char buf[4096 + 1];
-    int i, l;
+    char buf[4096 + 1], *p;
+    int i, j, l;
 
     // set option
     if (!set_option(option, argc, (const char **)argv)) {
@@ -122,14 +122,16 @@ int main(int argc, char *argv[]) {
             while (!feof(fpin)) {
                 tmp_str = "";
                 while (!feof(fpin)) {
-                    l = fread(buf, 1, 1, fpin);
-                    if (l <= 0) {
-                        continue;
-                    }
-                    buf[1] = '\0';
-                    tmp_str.add(buf);
-                    if (buf[l] == '\n') {
-                        break;
+                    l = fread(buf, 1, 4096, fpin);
+                    buf[l] = '\0';
+                    p = strrchr(buf, '\n');
+                    if (p != NULL) {
+                        j = p - buf + 1;
+                        tmp_str.add(buf, j);
+                        convert(tmp_str, option, fpout);
+                        tmp_str = buf + j;
+                    } else {
+                        tmp_str.add(buf);
                     }
                 }
                 if (0 < tmp_str.len()) {
